@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document::OpenAPI;
 # ABSTRACT: One OpenAPI v3.0, v3.1 or v3.2 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.122';
+our $VERSION = '0.123';
 
 use 5.020;
 use utf8;
@@ -19,7 +19,7 @@ no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 no if "$]" >= 5.041009, feature => 'smartmatch';
 no feature 'switch';
-use JSON::Schema::Modern::Utilities 0.625 qw(E canonical_uri jsonp is_equal json_pointer_type assert_keyword_type assert_uri_reference load_cached_document get_type);
+use JSON::Schema::Modern::Utilities 0.625 qw(E canonical_uri jsonp unjsonp is_equal json_pointer_type assert_keyword_type assert_uri_reference load_cached_document get_type);
 use JSON::Schema::Modern::Result 0.630;
 use OpenAPI::Modern::Utilities qw(:constants add_vocab_and_default_schemas);
 use Carp qw(croak carp);
@@ -588,7 +588,22 @@ sub upgrade ($self, $to_version = SUPPORTED_OAD_VERSIONS->[-1]) {
   return $schema if $from_oas_version eq $to_oas_version;
 
   if ($from_oas_version eq '3.0') {
-    delete $schema->{paths} if not keys $schema->{paths}->%*;
+    delete $schema->{paths} if not keys $schema->{paths}->%* and exists $schema->{components};
+
+    foreach my $media_type_path ($self->get_entity_locations('media-type')) {
+      my $media_type = (unjsonp($media_type_path))[-1];
+
+      # convert {"schema": {"type": "string", "format": "binary"}} to {}
+      if ($media_type eq 'application/octet-stream') {
+        my $media_type_obj = $self->get($media_type_path);
+        my $schema = $media_type_obj->{schema};
+        if ($schema and keys %$schema == 2
+            and ($schema->{type}//'') eq 'string' and ($schema->{format}//'') eq 'binary') {
+          delete $media_type_obj->{schema};
+          delete $self->_entities->{$media_type_path.'/schema'};
+        }
+      }
+    }
 
     foreach my $schema_path ($self->get_entity_locations('schema')) {
       my $subschema = $self->get($schema_path);
@@ -598,6 +613,9 @@ sub upgrade ($self, $to_version = SUPPORTED_OAD_VERSIONS->[-1]) {
           if delete $subschema->{nullable} and exists $subschema->{type};
       }
 
+      $subschema->{const} = (delete $subschema->{enum})->[0]
+        if exists $subschema->{enum} and $subschema->{enum}->@* == 1;
+
       $subschema->{exclusiveMinimum} = delete $subschema->{minimum} if delete $subschema->{exclusiveMinimum};
       $subschema->{exclusiveMaximum} = delete $subschema->{maximum} if delete $subschema->{exclusiveMaximum};
 
@@ -744,7 +762,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.0, v3.1 or v3.2 documen
 
 =head1 VERSION
 
-version 0.122
+version 0.123
 
 =head1 SYNOPSIS
 
